import { objectUid, bangleWarn } from '@bangle.dev/js-utils';
import PropTypes from 'prop-types';
import { Node } from 'prosemirror-model';
import { EditorView } from 'prosemirror-view';
import React from 'react';
const LOG = false;
let log = LOG ? console.log.bind(console, 'NodeViewWrapper') : () => { };
export class NodeViewWrapper extends React.PureComponent {
    constructor(props) {
        super(props);
        Object.defineProperty(this, "update", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "attachToContentDOM", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.update = () => {
            this.setState((_state, props) => ({
                nodeViewProps: props.nodeView.getNodeViewProps(),
            }));
        };
        this.attachToContentDOM = (reactElement) => {
            if (!reactElement) {
                return;
            }
            const contentDOM = this.props.nodeView.contentDOM;
            if (!reactElement.contains(contentDOM)) {
                if (contentDOM.parentNode) {
                    contentDOM.parentNode.removeChild(contentDOM);
                }
                reactElement.appendChild(contentDOM);
            }
        };
        props.nodeViewUpdateStore.set(props.nodeView, this.update);
        this.state = { nodeViewProps: this.props.nodeView.getNodeViewProps() };
    }
    getChildren() {
        if (!this.props.nodeView.contentDOM) {
            return null;
        }
        if (this.state.nodeViewProps.node.isInline) {
            return (React.createElement("span", { className: "bangle-nv-child-container", ref: this.attachToContentDOM }));
        }
        return (React.createElement("div", { className: "bangle-nv-child-container", ref: this.attachToContentDOM }));
    }
    render() {
        log('react rendering', objectUid.get(this.props.nodeView));
        const element = this.props.renderNodeViews({
            ...this.state.nodeViewProps,
            children: this.getChildren(),
        });
        if (!element) {
            bangleWarn('renderNodeView prop must return a react element for the node', this.state.nodeViewProps.node);
            throw new Error(`renderNodeView must handle rendering for node of type "${this.state.nodeViewProps.node.type.name}"`);
        }
        return element;
    }
}
Object.defineProperty(NodeViewWrapper, "propTypes", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        nodeView: PropTypes.object.isRequired,
        renderNodeViews: PropTypes.func.isRequired,
        nodeViewUpdateStore: PropTypes.instanceOf(WeakMap).isRequired,
    }
});
export const atomNodeViewPropTypes = {
    selected: PropTypes.bool.isRequired,
    node: PropTypes.instanceOf(Node).isRequired,
    view: PropTypes.instanceOf(EditorView).isRequired,
    getPos: PropTypes.func.isRequired,
    decorations: PropTypes.object.isRequired,
    attrs: PropTypes.object.isRequired,
    updateAttrs: PropTypes.func.isRequired,
};
export const nodeViewPropTypes = {
    ...atomNodeViewPropTypes,
    children: PropTypes.oneOfType([
        PropTypes.element,
        PropTypes.arrayOf(PropTypes.element),
    ]).isRequired,
};
