import { useEffect, useState } from 'react';
import { saveRenderHandlers } from '@bangle.dev/core';
import { objectUid } from '@bangle.dev/js-utils';
const LOG = false;
let log = LOG ? console.log.bind(console, 'node-view-helpers') : () => { };
export const nodeViewUpdateStore = new WeakMap();
export const nodeViewRenderHandlers = (updateNodeViews) => ({
    create: (nodeView, _nodeViewProps) => {
        log('create', objectUid.get(nodeView));
        updateNodeViews((nodeViews) => [...nodeViews, nodeView]);
    },
    update: (nodeView, _nodeViewProps) => {
        log('update', objectUid.get(nodeView));
        const updateCallback = nodeViewUpdateStore.get(nodeView);
        if (updateCallback) {
            updateCallback();
        }
    },
    destroy: (nodeView) => {
        log('destroy', objectUid.get(nodeView));
        updateNodeViews((nodeViews) => nodeViews.filter((n) => n !== nodeView));
    },
});
export function useNodeViews(ref) {
    const [nodeViews, setNodeViews] = useState([]);
    useEffect(() => {
        let destroyed = false;
        saveRenderHandlers(ref.current, nodeViewRenderHandlers((cb) => {
            if (!destroyed) {
                setNodeViews((nodeViews) => cb(nodeViews));
            }
        }));
        return () => {
            destroyed = true;
        };
    }, [ref]);
    return nodeViews;
}
